==> plasma-desktop-5.6.2.tar.xz: plasma-desktop-5.6.2/containments/desktop/plugins/folder/menuhelper.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef MENUHELPER_H
#define MENUHELPER_H

#include <QObject>

class QAction;
class QMenu;

class MenuHelper : public QObject
{
    Q_OBJECT

    public:
        MenuHelper(QObject *parent = 0);
        ~MenuHelper();

        Q_INVOKABLE QString iconName(QAction *action);

        Q_INVOKABLE void setMenu(QAction *action, QObject *menu);
};

#endif

==> plasma-desktop-5.12.1.tar.xz: plasma-desktop-5.12.1/containments/desktop/plugins/folder/menuhelper.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef MENUHELPER_H
#define MENUHELPER_H

#include <QObject>

class QAction;

class MenuHelper : public QObject
{
    Q_OBJECT

    public:
        explicit MenuHelper(QObject *parent = nullptr);
        ~MenuHelper();

        Q_INVOKABLE QString iconName(QAction *action) const;

        Q_INVOKABLE void setMenu(QAction *action, QObject *menu);
};

#endif
